#[non_exhaustive]pub enum ClientOperationError {
RequestChannelClosed,
RequestChannelFull,
}Expand description
Errors when handing an operation to the MQTT client’s request queue.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
RequestChannelClosed
The request channel to the event loop is closed (client shut down)
RequestChannelFull
The request channel to the event loop is full (backpressure)