#[non_exhaustive]pub enum DisconnectReasonCode {
Show 29 variants
NormalDisconnection,
DisconnectWithWillMessage,
UnspecifiedError,
MalformedPacket,
ProtocolError,
ImplementationSpecificError,
NotAuthorized,
ServerBusy,
ServerShuttingDown,
KeepAliveTimeout,
SessionTakenOver,
TopicFilterInvalid,
TopicNameInvalid,
ReceiveMaximumExceeded,
TopicAliasInvalid,
PacketTooLarge,
MessageRateTooHigh,
QuotaExceeded,
AdministrativeAction,
PayloadFormatInvalid,
RetainNotSupported,
QoSNotSupported,
UseAnotherServer,
ServerMoved,
SharedSubscriptionNotSupported,
ConnectionRateExceeded,
MaximumConnectTime,
SubscriptionIdentifiersNotSupported,
WildcardSubscriptionsNotSupported,
}Expand description
MQTT 5 DISCONNECT reason code, surfaced on
DisconnectReason::BrokerDisconnected.
Modeled as the MQTT 5 reason-code set; MQTT 3.1.1 has no disconnect reason code, so this is only ever populated on a v5 connection.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
NormalDisconnection
Normal disconnection (0x00)
DisconnectWithWillMessage
Disconnect with Will Message (0x04)
UnspecifiedError
Unspecified error (0x80)
MalformedPacket
Malformed packet (0x81)
ProtocolError
Protocol error (0x82)
ImplementationSpecificError
Implementation-specific error (0x83)
NotAuthorized
Not authorized (0x87)
ServerBusy
Server busy (0x89)
ServerShuttingDown
Server shutting down (0x8B)
KeepAliveTimeout
Keep-alive timeout (0x8D)
SessionTakenOver
Session taken over by another connection with the same client id (0x8E)
TopicFilterInvalid
Topic filter invalid (0x8F)
TopicNameInvalid
Topic name invalid (0x90)
ReceiveMaximumExceeded
Receive maximum exceeded (0x93)
TopicAliasInvalid
Topic alias invalid (0x94)
PacketTooLarge
Packet too large (0x95)
MessageRateTooHigh
Message rate too high (0x96)
QuotaExceeded
Quota exceeded (0x97)
AdministrativeAction
Administrative action (0x98)
PayloadFormatInvalid
Payload format invalid (0x99)
RetainNotSupported
Retain not supported (0x9A)
QoSNotSupported
QoS not supported (0x9B)
UseAnotherServer
Use another server (0x9C)
ServerMoved
Server moved (0x9D)
Shared subscriptions not supported (0x9E)
ConnectionRateExceeded
Connection rate exceeded (0x9F)
MaximumConnectTime
Maximum connect time exceeded (0xA0)
SubscriptionIdentifiersNotSupported
Subscription identifiers not supported (0xA1)
WildcardSubscriptionsNotSupported
Wildcard subscriptions not supported (0xA2)